@@ -23,14 +23,15 @@ import contextlib
 import logging
 import random
 import time
-from typing import TYPE_CHECKING, Callable
+from collections.abc import Callable
+from typing import TYPE_CHECKING
 
 from aiohttp import ClientSession
 from gcloud.aio.auth import AioSession, Token
 from googleapiclient.discovery import Resource, build
 from googleapiclient.errors import HttpError
 
-from airflow.exceptions import AirflowException
+from airflow.providers.common.compat.sdk import AirflowException
 from airflow.providers.google.common.hooks.base_google import (
     PROVIDE_PROJECT_ID,
     GoogleBaseAsyncHook,
@@ -78,8 +79,7 @@ def _poll_with_exponential_delay(
             if e.resp.status != 429:
                 log.info("Something went wrong. Not retrying: %s", format(e))
                 raise
-            else:
-                time.sleep((2**i) + random.random())
+            time.sleep((2**i) + random.random())
 
     raise ValueError(f"Connection could not be established after {max_n} retries.")
 
@@ -219,12 +219,11 @@ class MLEngineHook(GoogleBaseHook):
             if e.resp.status == 404:
                 self.log.error("Job with job_id %s does not exist. ", job_id)
                 raise
-            elif e.resp.status == 400:
+            if e.resp.status == 400:
                 self.log.info("Job with job_id %s is already complete, cancellation aborted.", job_id)
                 return {}
-            else:
-                self.log.error("Failed to cancel MLEngine job: %s", e)
-                raise
+            self.log.error("Failed to cancel MLEngine job: %s", e)
+            raise
 
     def get_job(self, project_id: str, job_id: str) -> dict:
         """
@@ -589,7 +588,7 @@ class MLEngineAsyncHook(GoogleBaseAsyncHook):
                 job = await self.get_job(
                     project_id=project_id,
                     job_id=job_id,
-                    session=session,  #  type: ignore
+                    session=session,  # type: ignore
                 )
                 job = await job.json(content_type=None)
                 self.log.info("Retrieving json_response: %s", job)
