@@ -20,7 +20,7 @@ from __future__ import annotations
 
 import asyncio
 import json
-from collections.abc import Sequence
+from collections.abc import Collection, Iterable, Sequence
 from datetime import datetime
 from typing import Any
 
@@ -28,7 +28,7 @@ from dateutil import parser
 from google.api_core.exceptions import NotFound
 from google.cloud.orchestration.airflow.service_v1.types import ExecuteAirflowCommandResponse
 
-from airflow.exceptions import AirflowException
+from airflow.providers.common.compat.sdk import AirflowException
 from airflow.providers.google.cloud.hooks.cloud_composer import CloudComposerAsyncHook
 from airflow.triggers.base import BaseTrigger, TriggerEvent
 
@@ -346,3 +346,185 @@ class CloudComposerDAGRunTrigger(BaseTrigger):
                 }
             )
             return
+
+
+class CloudComposerExternalTaskTrigger(BaseTrigger):
+    """The trigger wait for the external task completion."""
+
+    def __init__(
+        self,
+        project_id: str,
+        region: str,
+        environment_id: str,
+        start_date: datetime,
+        end_date: datetime,
+        allowed_states: list[str],
+        skipped_states: list[str],
+        failed_states: list[str],
+        composer_external_dag_id: str,
+        composer_external_task_ids: Collection[str] | None = None,
+        composer_external_task_group_id: str | None = None,
+        gcp_conn_id: str = "google_cloud_default",
+        impersonation_chain: str | Sequence[str] | None = None,
+        poll_interval: int = 10,
+        composer_airflow_version: int = 2,
+    ):
+        super().__init__()
+        self.project_id = project_id
+        self.region = region
+        self.environment_id = environment_id
+        self.start_date = start_date
+        self.end_date = end_date
+        self.allowed_states = allowed_states
+        self.skipped_states = skipped_states
+        self.failed_states = failed_states
+        self.composer_external_dag_id = composer_external_dag_id
+        self.composer_external_task_ids = composer_external_task_ids
+        self.composer_external_task_group_id = composer_external_task_group_id
+        self.gcp_conn_id = gcp_conn_id
+        self.impersonation_chain = impersonation_chain
+        self.poll_interval = poll_interval
+        self.composer_airflow_version = composer_airflow_version
+
+    def serialize(self) -> tuple[str, dict[str, Any]]:
+        return (
+            "airflow.providers.google.cloud.triggers.cloud_composer.CloudComposerExternalTaskTrigger",
+            {
+                "project_id": self.project_id,
+                "region": self.region,
+                "environment_id": self.environment_id,
+                "start_date": self.start_date,
+                "end_date": self.end_date,
+                "allowed_states": self.allowed_states,
+                "skipped_states": self.skipped_states,
+                "failed_states": self.failed_states,
+                "composer_external_dag_id": self.composer_external_dag_id,
+                "composer_external_task_ids": self.composer_external_task_ids,
+                "composer_external_task_group_id": self.composer_external_task_group_id,
+                "gcp_conn_id": self.gcp_conn_id,
+                "impersonation_chain": self.impersonation_chain,
+                "poll_interval": self.poll_interval,
+                "composer_airflow_version": self.composer_airflow_version,
+            },
+        )
+
+    async def _get_task_instances(self, start_date: str, end_date: str) -> list[dict]:
+        """Get the list of task instances."""
+        try:
+            environment = await self.gcp_hook.get_environment(
+                project_id=self.project_id,
+                region=self.region,
+                environment_id=self.environment_id,
+            )
+        except NotFound as not_found_err:
+            self.log.info("The Composer environment %s does not exist.", self.environment_id)
+            raise AirflowException(not_found_err)
+        composer_airflow_uri = environment.config.airflow_uri
+
+        self.log.info(
+            "Pulling the DAG '%s' task instances from the '%s' environment...",
+            self.composer_external_dag_id,
+            self.environment_id,
+        )
+        task_instances_response = await self.gcp_hook.get_task_instances(
+            composer_airflow_uri=composer_airflow_uri,
+            composer_dag_id=self.composer_external_dag_id,
+            query_parameters={
+                "execution_date_gte" if self.composer_airflow_version < 3 else "logical_date_gte": start_date,
+                "execution_date_lte" if self.composer_airflow_version < 3 else "logical_date_lte": end_date,
+            },
+        )
+        task_instances = task_instances_response["task_instances"]
+
+        if self.composer_external_task_ids:
+            task_instances = [
+                task_instance
+                for task_instance in task_instances
+                if task_instance["task_id"] in self.composer_external_task_ids
+            ]
+        elif self.composer_external_task_group_id:
+            task_instances = [
+                task_instance
+                for task_instance in task_instances
+                if self.composer_external_task_group_id in task_instance["task_id"].split(".")
+            ]
+
+        return task_instances
+
+    def _check_task_instances_states(
+        self,
+        task_instances: list[dict],
+        start_date: datetime,
+        end_date: datetime,
+        states: Iterable[str],
+    ) -> bool:
+        for task_instance in task_instances:
+            if (
+                start_date.timestamp()
+                < parser.parse(
+                    task_instance["execution_date" if self.composer_airflow_version < 3 else "logical_date"]
+                ).timestamp()
+                < end_date.timestamp()
+            ) and task_instance["state"] not in states:
+                return False
+        return True
+
+    def _get_async_hook(self) -> CloudComposerAsyncHook:
+        return CloudComposerAsyncHook(
+            gcp_conn_id=self.gcp_conn_id,
+            impersonation_chain=self.impersonation_chain,
+        )
+
+    async def run(self):
+        self.gcp_hook: CloudComposerAsyncHook = self._get_async_hook()
+        try:
+            while True:
+                task_instances = await self._get_task_instances(
+                    start_date=self.start_date.strftime("%Y-%m-%dT%H:%M:%SZ"),
+                    end_date=self.end_date.strftime("%Y-%m-%dT%H:%M:%SZ"),
+                )
+
+                if len(task_instances) == 0:
+                    self.log.info("Task Instances are empty. Sensor waits for task instances...")
+                    self.log.info("Sleeping for %s seconds.", self.poll_interval)
+                    await asyncio.sleep(self.poll_interval)
+                    continue
+
+                if self.failed_states and self._check_task_instances_states(
+                    task_instances=task_instances,
+                    start_date=self.start_date,
+                    end_date=self.end_date,
+                    states=self.failed_states,
+                ):
+                    yield TriggerEvent({"status": "failed"})
+                    return
+
+                if self.skipped_states and self._check_task_instances_states(
+                    task_instances=task_instances,
+                    start_date=self.start_date,
+                    end_date=self.end_date,
+                    states=self.skipped_states,
+                ):
+                    yield TriggerEvent({"status": "skipped"})
+                    return
+
+                self.log.info("Sensor waits for allowed states: %s", self.allowed_states)
+                if self._check_task_instances_states(
+                    task_instances=task_instances,
+                    start_date=self.start_date,
+                    end_date=self.end_date,
+                    states=self.allowed_states,
+                ):
+                    yield TriggerEvent({"status": "success"})
+                    return
+
+                self.log.info("Sleeping for %s seconds.", self.poll_interval)
+                await asyncio.sleep(self.poll_interval)
+        except AirflowException as ex:
+            yield TriggerEvent(
+                {
+                    "status": "error",
+                    "message": str(ex),
+                }
+            )
+            return
